package nl.uvt.commons.xml;

import nu.xom.*;

/**
 * Namespace URIs.
 */
public class Namespaces {

  public static final String ACIS_NAMESPACE_URI = "http://acis.openlib.org/";
  public static final String AMF_NAMESPACE_URI = "http://amf.openlib.org";
  public static final String CTX_NAMESPACE_URI = "info:ofi/fmt:xml:xsd:ctx";
  public static final String DAI_NAMESPACE_URI = "info:eu-repo/dai";
  public static final String DC_NAMESPACE_URI = "http://purl.org/dc/elements/1.1/";
  public static final String DCTERMS_NAMESPACE_URI = "http://purl.org/dc/terms/";
  public static final String DD_NAMESPACE_URI = "http://namespace.meresco.org/drilldown";
  public static final String DDI_NAMESPACE_URI = "http://www.icpsr.umich.edu/DDI";
  public static final String DIDL_NAMESPACE_URI = "urn:mpeg:mpeg21:2002:02-DIDL-NS";
  public static final String DIDMODEL_NAMESPACE_URI = "urn:mpeg:mpeg21:2002:02-DIDMODEL-NS";
  public static final String DII_NAMESPACE_URI = "urn:mpeg:mpeg21:2002:01-DII-NS";
  public static final String DIP_2005_NAMESPACE_URI = "urn:mpeg:mpeg21:2005:01-DIP-NS";
  public static final String DIP_2002_NAMESPACE_URI = "urn:mpeg:mpeg21:2002:01-DIP-NS";
  public static final String FO_NAMESPACE_URI = "http://www.w3.org/1999/XSL/Format";
  public static final String FOAF_NAMESPACE_URI = "http://xmlns.com/foaf/0.1/";
  public static final String META_NAMESPACE_URI = "http://meresco.com/namespace/harvester/meta";
  public static final String MODS_NAMESPACE_URI = "http://www.loc.gov/mods/v3";
  public static final String NEREUS_NAMESPACE_URI = "http://www.nereus4economics.info/";
  public static final String OAI_NAMESPACE_URI = "http://www.openarchives.org/OAI/2.0/";
  public static final String PUBL_NAMESPACE_URI = "http://www.uvt.nl/publications/xsd/2007-1";
  public static final String RDF_NAMESPACE_URI = "http://www.w3.org/1999/02/22-rdf-syntax-ns#";
  public static final String SRW_NAMESPACE_URI = "http://www.loc.gov/zing/srw/";
  public static final String SRWDIAG_NAMESPACE_URI = "http://www.loc.gov/zing/srw/diagnostic/";
  public static final String UCP_NAMESPACE_URI = "http://www.loc.gov/ucp";
  public static final String WC_RESOLVER_URI = "http://worldcatlibraries.org/registry/resolver";
  public static final String XML_NAMESPACE_URI = "http://www.w3.org/XML/1998/namespace";
  public static final String XSI_NAMESPACE_URI = "http://www.w3.org/2001/XMLSchema-instance";
  
  private static Object classLock = Namespaces.class;
  private static XPathContext context;
  
  /**
   * Associates some namespace URI's with a prefix for use in XPath queries.
   * 
   * <p>If you want to use XOM's query() method to find nodes with an XPath
   * statement in a document with namespaces, prefixes you use in the
   * XPath query must be associated with the proper namespace URI. This method
   * returns a context object to be used in the query-method.</p>
   * 
   * @return context object that can be used in your query
   */
  public static XPathContext getContext() {
    synchronized (classLock) {
      if (context == null) {
        context = new XPathContext();
        context.addNamespace("acis", ACIS_NAMESPACE_URI);
        context.addNamespace("amf", AMF_NAMESPACE_URI);
        context.addNamespace("ctx", CTX_NAMESPACE_URI);
        context.addNamespace("dai", DAI_NAMESPACE_URI);
        context.addNamespace("dc", DC_NAMESPACE_URI);
        context.addNamespace("dcterms", DCTERMS_NAMESPACE_URI);
        context.addNamespace("dd", DD_NAMESPACE_URI);
        context.addNamespace("ddi", DDI_NAMESPACE_URI);
        context.addNamespace("didl", DIDL_NAMESPACE_URI);
        context.addNamespace("didmodel", DIDMODEL_NAMESPACE_URI);
        context.addNamespace("dii", DII_NAMESPACE_URI);
        context.addNamespace("dip_2002", DIP_2002_NAMESPACE_URI);
        context.addNamespace("dip", DIP_2005_NAMESPACE_URI);
        context.addNamespace("fo", FO_NAMESPACE_URI);
        context.addNamespace("foaf", FOAF_NAMESPACE_URI);
        context.addNamespace("meta", META_NAMESPACE_URI);
        context.addNamespace("mods", MODS_NAMESPACE_URI);
        context.addNamespace("nereus", NEREUS_NAMESPACE_URI);
        context.addNamespace("oai", OAI_NAMESPACE_URI);
        context.addNamespace("publ", PUBL_NAMESPACE_URI);
        context.addNamespace("rdf", RDF_NAMESPACE_URI);
        context.addNamespace("srw", SRW_NAMESPACE_URI);
        context.addNamespace("srwdiag", SRWDIAG_NAMESPACE_URI);
        context.addNamespace("ucp", UCP_NAMESPACE_URI);
        context.addNamespace("wc_resolver", WC_RESOLVER_URI);
        context.addNamespace("xml", XML_NAMESPACE_URI);
        context.addNamespace("xsi", XSI_NAMESPACE_URI);
        // Huh?? xslns prefix for xmlns uri
        // context.addNamespace("xslns", "http://www.w3.org/2000/xmlns/");
      }
      return context;
    }
  }
}
