package nl.uvt.commons.xml;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;

import javax.xml.transform.Source;
import javax.xml.transform.stream.StreamSource;
import javax.xml.validation.*;

import nu.xom.Document;
import org.xml.sax.SAXException;


public class Validation {
  /*
   * Based on http://www.ibm.com/developerworks/xml/library/x-javaxmlvalidapi.html
   */
  public static Validator makeValidator(File schema)
  throws FileNotFoundException, SAXException {
    SchemaFactory factory = 
      SchemaFactory.newInstance("http://www.w3.org/2001/XMLSchema");
    if (! schema.exists())
      throw new FileNotFoundException("XSD file "+schema.getAbsolutePath()+" not found in validate()");
    Schema schemaSchema = factory.newSchema(schema);
    Validator validator = schemaSchema.newValidator();
    return validator; 
  }
  public static Validator makeValidator(InputStream schema)
  throws FileNotFoundException, SAXException {
    SchemaFactory factory = 
      SchemaFactory.newInstance("http://www.w3.org/2001/XMLSchema");
    Source source = new StreamSource(schema);
    Schema schemaSchema = factory.newSchema(source);
    Validator validator = schemaSchema.newValidator();
    return validator; 
  }
  public static void validate(InputStream document, Validator validator)
  throws FileNotFoundException, IOException, SAXException  {
    Source source = new StreamSource(document);
    validator.validate(source);
  }
  public static void validate(Document document, Validator validator)
  throws SAXException, IOException {
    // Convert document to string and make an inputstream of this string:
    InputStream bais = new ByteArrayInputStream(document.toXML().getBytes()); 
    validate(bais, validator);
  }


}
