package nl.uvt.commons.xml;

import java.io.*;
import nu.xom.*;
import nu.xom.xinclude.*;

public class XIncluder {
  /**
   * Resolves every XInclude element.
   * 
   * <p>Uses XOM's XIncluder to resolve XInclude elements.</p>
   * 
   * <p>As a convenience service the method removes xml:base attributes that
   * must be added according to the XInclude standards. The xml:base
   * attributes can cause problems when checking the validity of a
   * document against XSD schemas.</p>
   * 
   * <p>Use the contents of the exception, if one is thrown, to report
   * problems to the issuer of the document.</p>  
   *  
   * @param doc the document with XInclude elements
   * @return the document with XInclude elements replaced by the
   * contents of the documents referred by the href attribute or by the
   * contents of the fallback element.
   * @throws IOException if an included document could not be loaded, and no
   * fallback was available (source: XOM Javadoc)
   * @throws ParsingException if an included XML document was malformed (source:
   * XOM Javadoc)
   * @throws XIncludeException if the document violates the syntax rules of
   * XInclude (source: XOM Javadoc)
   * @see nu.xom.xinclude.XIncluder#resolve(Utilities)
   */
  public static Document resolveXIncludes(Document doc)
  throws IOException, ParsingException, XIncludeException {
    Document document = nu.xom.xinclude.XIncluder.resolve(doc);
    Element rootElement = document.getRootElement();
    Nodes attributes = rootElement.query("//@xml:base", nl.uvt.commons.xml.Namespaces.getContext());
    Node attribute;
    for (int i=0; i<attributes.size(); i++) { 
      attribute = attributes.get(i);
      attribute.detach();
    }
    rootElement.removeNamespaceDeclaration("xinclude");
    return document;
  }
}
